==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Preferencje &amp;aplikacji
Preferencje aplikacji
Ogólne ustawienia aplikacji</translatorcomment>
        <translation type="unfinished">Preferencje aplikacji</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Preferencje bieżącego rysunku
&amp;Preferencje bieżącego rysunku</translatorcomment>
        <translation type="unfinished">Preferencje rysowania</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wymaga ponownego uruchomienia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę zrestartować QCad na zmiany preferencji odniosły skutek.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Edycja
&amp;Edytuj blok</translatorcomment>
        <translation type="unfinished">&amp;Edycja</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Preferencje
Preferencje…
Preferencje &amp;aplikacji</translatorcomment>
        <translation type="unfinished">Preferencje…</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Filtr:
Filtr
Brak argumentu dla filtru.</translatorcomment>
        <translation type="unfinished">Filtr</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wyczyść wyszukiwanie</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rozwiń drzewo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Drzewo Collapse</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przywrócić do wartości domyślnych</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Preferencje &amp;aplikacji
Preferencje aplikacji
Ogólne ustawienia aplikacji</translatorcomment>
        <translation>Preferencje programu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Preferencje bieżącego rysunku
&amp;Preferencje bieżącego rysunku</translatorcomment>
        <translation>Preferencje rysowania</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation type="unfinished">Zastosuj preferencje</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wymagane ponowne uruchomienie programu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę ponownie uruchomić program QCAD,
aby wprowadzić zmiany preferencji.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Domyślne dla</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>To są domyślne preferencje dla nowych rysunków.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Preferencje aktualnego rysunku można zmienić w &lt;br/&gt;&lt;i&gt;Edycja &amp;gt; Preferencje rysowania&lt;/i&gt;.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Zmiany zostaną wprowadzone do nowych rysunków, lecz NIE do aktualnego rysunku.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Narzędzia edycji</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Wyświetla narzędzia edycji</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Edycja
&amp;Edytuj blok</translatorcomment>
        <translation>&amp;Edycja</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Preferencje
Preferencje…
Preferencje &amp;aplikacji</translatorcomment>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Filtr:
Filtr
Brak argumentu dla filtru.</translatorcomment>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyczyść wyszukiwanie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rozwiń drzewo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zwiń drzewo</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przywróć wartości domyślne</translation>
    </message>
</context>
</TS>
